diff --git a/README.md b/README.md
index a4024cf..b2430da 100644
--- a/README.md
+++ b/README.md
@@ -1,4 +1,4 @@
-
+
## Myxelium's Battlemap Importer
@@ -7,7 +7,7 @@ Effortlessly turn single images or exported map data into ready‑to‑play Foun
### What it is
-Quick Battlemap Importer is a Foundry VTT module that adds a simple "Quick import" button to the Scenes sidebar. It opens a window where you can drag and drop a background image or video and, if you have it, a JSON configuration file. The module uploads the media, applies grid settings, creates walls, lights and doors etc, and builds a new scene for you automatically.
+Myxeliums Battlemap Importer is a Foundry VTT module that adds a simple "Quick import" button to the Scenes sidebar. It opens a window where you can drag and drop a background image or video and, if you have it, a JSON configuration file. The module uploads the media, applies grid settings, creates walls, lights and doors etc, and builds a new scene for you automatically.
### Why it exists
@@ -15,8 +15,8 @@ Setting up scenes manually can be slow: uploading backgrounds, measuring grid si
### Inside foundry
-
-
+
+
@@ -38,7 +38,7 @@ Setting up scenes manually can be slow: uploading backgrounds, measuring grid si
## Compatibility
-- Foundry VTT compatibility: minimum 10, verified 12
+- Foundry VTT compatibility: minimum 12, verified 13
## Installation
@@ -50,7 +50,7 @@ Setting up scenes manually can be slow: uploading backgrounds, measuring grid si
Manual download (optional):
-- Download ZIP: https://github.com/Myxelium/FoundryVTT-Quick-Import/releases/latest/download/quick-battlemap-importer.zip
+- Download ZIP: https://github.com/Myxelium/FoundryVTT-Quick-Import/releases/latest/download/myxeliums-battlemap-importer.zip
## Usage
@@ -79,7 +79,3 @@ The module uploads the media to your world, applies grid settings (auto-detected
## Credits
- Author: Myxelium (https://github.com/Myxelium)
-
-## License
-
-MIT
diff --git a/images/image1.png b/images/image1.png
new file mode 100644
index 0000000..50d3fe4
Binary files /dev/null and b/images/image1.png differ
diff --git a/images/importer.png b/images/importer.png
new file mode 100644
index 0000000..94545e9
Binary files /dev/null and b/images/importer.png differ
diff --git a/languages/en.json b/languages/en.json
index 8139838..0570ebf 100644
--- a/languages/en.json
+++ b/languages/en.json
@@ -1,8 +1,8 @@
{
"QUICKBATTLEMAP": {
- "Ready": "Quick Battlemap module is ready",
- "DropAreaTitle": "Quick Battlemap Importer",
- "DropInstructions": "Drop background images/videos and optionally JSON files with walls",
+ "Ready": "Myxeliums Battlemap Importer is ready",
+ "DropAreaTitle": "Myxeliums Battlemap Importer",
+ "DropInstructions": "Drop background images/videos and optionally JSON files with wall/light data here to create battlemap scenes.",
"DropInstructionsMore": "Multiple files can be dropped to create multi-floor scenes (requires Levels module). Files with matching names will be paired automatically.",
"BackgroundStatus": "Background Media",
"WallDataStatus": "Wall Data",
@@ -15,7 +15,7 @@
"SceneCreationFailed": "Failed to create scene",
"InvalidJSON": "The JSON file could not be parsed",
"DefaultSceneName": "New Battlemap",
- "ControlTitle": "Quick Battlemap Importer",
+ "ControlTitle": "Myxeliums Battlemap Importer",
"Options": "Options",
"NoGridLabel": "Create scene with no grid",
"NoGridHint": "Skips applying or detecting a grid. Useful for maps without visible grid lines.",
diff --git a/module.json b/module.json
index 4fdc2a9..2e6c05c 100644
--- a/module.json
+++ b/module.json
@@ -1,8 +1,8 @@
{
"id": "quick-battlemap-importer",
- "title": "Quick Battlemap Importer",
+ "title": "Myxeliums Battlemap Importer",
"description": "Import battlemaps by simply dragging in a background image and wall/light data JSON file",
- "version": "1.5.4",
+ "version": "1.5.10",
"compatibility": {
"minimum": "10",
"verified": "13"
@@ -13,8 +13,8 @@
"url": "https://github.com/Myxelium"
}
],
- "esmodules": ["scripts/quick-battlemap.js"],
- "styles": ["styles/quick-battlemap.css"],
+ "esmodules": ["scripts/myxeliums-battlemap.js"],
+ "styles": ["styles/myxeliums-battlemap.css"],
"languages": [
{
"lang": "en",
@@ -23,6 +23,6 @@
}
],
"url": "https://github.com/Myxelium/FoundryVTT-Quick-Import",
- "manifest": "https://github.com/Myxelium/FoundryVTT-Quick-Import-Dev/releases/download/1.5.4/module.json",
- "download": "https://github.com/Myxelium/FoundryVTT-Quick-Import-Dev/releases/download/1.5.4/quick-battlemap-importer.zip"
+ "manifest": "https://github.com/Myxelium/FoundryVTT-Quick-Import/releases/latest/download/module.json",
+ "download": "https://github.com/Myxelium/FoundryVTT-Quick-Import/releases/latest/download/myxeliums-battlemap-importer.zip"
}
diff --git a/scripts/lib/file-processor.js b/scripts/lib/file-processor.js
index a4e6051..c27675a 100644
--- a/scripts/lib/file-processor.js
+++ b/scripts/lib/file-processor.js
@@ -8,7 +8,7 @@
*/
/** Module identifier for console logging */
-const MODULE_LOG_PREFIX = 'Quick Battlemap Importer';
+const MODULE_LOG_PREFIX = 'Myxeliums Battlemap Importer';
/**
* @typedef {Object} ProcessedImageData
diff --git a/scripts/lib/import-panel-view.js b/scripts/lib/import-panel-view.js
index 60c27a6..9bb7dac 100644
--- a/scripts/lib/import-panel-view.js
+++ b/scripts/lib/import-panel-view.js
@@ -19,7 +19,7 @@
/** CSS selectors for frequently accessed elements */
const PANEL_SELECTORS = {
- PANEL_ROOT: '#quick-battlemap-drop-area',
+ PANEL_ROOT: '#myxeliums-battlemap-drop-area',
CREATE_BUTTON: '.create-scene-button',
RESET_BUTTON: '.reset-button',
CLOSE_BUTTON: '.header-button.close',
@@ -35,7 +35,7 @@ const PANEL_SELECTORS = {
};
/** LocalStorage key for persisting no-grid preference */
-const NO_GRID_STORAGE_KEY = 'quick-battlemap:no-grid';
+const NO_GRID_STORAGE_KEY = 'myxeliums-battlemap:no-grid';
/**
* View class that manages the import panel DOM and user interactions.
@@ -83,7 +83,7 @@ export class ImportPanelView {
}
// Remove any existing panel to prevent duplicates
- const existingPanel = document.getElementById('quick-battlemap-drop-area');
+ const existingPanel = document.getElementById('myxeliums-battlemap-drop-area');
if (existingPanel) {
existingPanel.remove();
}
@@ -138,7 +138,7 @@ export class ImportPanelView {
` : '';
return `
-
diff --git a/release.sh b/release.sh
index 3d64b0f..f7e1f59 100755
--- a/release.sh
+++ b/release.sh
@@ -1,12 +1,12 @@
#!/bin/bash
# Release script for Quick Battlemap Importer
# Increments version in module.json and creates a release zip
set -e
MODULE_FILE="module.json"
-ZIP_NAME="quick-battlemap-importer.zip"
+ZIP_NAME="myxeliums-battlemap-importer.zip"
# Check if module.json exists
if [ ! -f "$MODULE_FILE" ]; then
@@ -1,12 +1,12 @@
#!/bin/bash
-# Release script for Quick Battlemap Importer
+# Release script for Myxeliums Battlemap Importer
# Increments version in module.json and creates a release zip
set -e